Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(147)

Unified Diff: src/vm/main_simple.cc

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/vm/main.cc ('k') | src/vm/mark_sweep.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/vm/main_simple.cc
diff --git a/src/vm/main_simple.cc b/src/vm/main_simple.cc
index ae747ce5a0eae0985995381682d6b041d955dc5c..822a951122e2054aab4a20241772566e585dc3ca 100644
--- a/src/vm/main_simple.cc
+++ b/src/vm/main_simple.cc
@@ -2,20 +2,20 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-#ifndef FLETCH_ENABLE_LIVE_CODING
+#ifndef DARTINO_ENABLE_LIVE_CODING
#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
-#include "include/fletch_api.h"
+#include "include/dartino_api.h"
#include "src/shared/flags.h"
#include "src/shared/list.h"
#include "src/shared/utils.h"
#include "src/shared/platform.h"
-namespace fletch {
+namespace dartino {
static bool IsSnapshot(List<uint8> snapshot) {
return snapshot.length() > 2 && snapshot[0] == 0xbe && snapshot[1] == 0xef;
@@ -23,39 +23,39 @@ static bool IsSnapshot(List<uint8> snapshot) {
static int Main(int argc, char** argv) {
Flags::ExtractFromCommandLine(&argc, argv);
- FletchSetup();
+ DartinoSetup();
int program_count = argc - 1;
- FletchProgram* programs = new FletchProgram[program_count];
+ DartinoProgram* programs = new DartinoProgram[program_count];
for (int i = 0; i < program_count; i++) {
// Handle the arguments.
const char* input = argv[i + 1];
List<uint8> bytes = Platform::LoadFile(input);
if (!IsSnapshot(bytes)) {
- FATAL("The input file is not a fletch snapshot.");
+ FATAL("The input file is not a dartino snapshot.");
}
- FletchProgram program = FletchLoadSnapshot(bytes.data(), bytes.length());
+ DartinoProgram program = DartinoLoadSnapshot(bytes.data(), bytes.length());
programs[i] = program;
}
- int result = FletchRunMultipleMain(program_count, programs);
+ int result = DartinoRunMultipleMain(program_count, programs);
for (int i = 0; i < program_count; i++) {
- FletchDeleteProgram(programs[i]);
+ DartinoDeleteProgram(programs[i]);
}
delete[] programs;
- FletchTearDown();
+ DartinoTearDown();
return result;
}
-} // namespace fletch
+} // namespace dartino
-// Forward main calls to fletch::Main.
-int main(int argc, char** argv) { return fletch::Main(argc, argv); }
+// Forward main calls to dartino::Main.
+int main(int argc, char** argv) { return dartino::Main(argc, argv); }
-#endif // !FLETCH_ENABLE_LIVE_CODING
+#endif // !DARTINO_ENABLE_LIVE_CODING
« no previous file with comments | « src/vm/main.cc ('k') | src/vm/mark_sweep.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698